==> dasu_4.11.jar: edu/northwestern/dasu/util/RulesVerifier.java <==
/**
 * Dasu Project
 *
 * File:         RulesVerifier.java
 * RCS:          $Id: RulesVerifier.java,v 1.0 Jan 13, 2013 11:18:13 AM mas939 Exp $
 * Description:  RulesVerifier class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Jan 13, 2013 at 11:18:13 AM
 * Language:     Java
 * Package:      edu.northwestern.dasu.util
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2013, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.util;

import java.io.BufferedReader;
import java.io.File;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.net.Socket;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.DefaultLogger;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.taskdefs.Java;
import org.apache.tools.ant.types.Path;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The RulesVerifier class ...
 */
public class RulesVerifier {

	java.util.logging.Logger LOGGER;
	
	Runnable verifierServer = null;
	SocketClient verifierClient = null;	
	int timeout = 10; //seconds
	boolean ready = false;
	boolean failed = false;
	
	public RulesVerifier(java.util.logging.Logger logger){
		LOGGER = logger;
	}	
	
	public void initRulesVerifier() {
		
		LOGGER.info("UPDATER: initializing dynamic rules verifier...");
		verifierServer = new Runnable() {
			
			public void run() {
								
		        Project project = new Project();
		        project.setBaseDir(new File(System.getProperty("user.dir")));
		        project.init();
		        DefaultLogger logger = new DefaultLogger();
		        project.addBuildListener(logger);
		
		        logger.setOutputPrintStream(System.err);        
		        logger.setErrorPrintStream(System.err);
		        //logger.setMessageOutputLevel(Project.MSG_ERR);
		        
		        project.fireBuildStarted();
		    	logger.setMessageOutputLevel(Project.MSG_INFO);
		
		        Throwable caught = null;
		        try {
			        	
		    		Java javaTask = new Java();	    		
		            javaTask.setTaskName("rulesVerifier");
		            javaTask.setProject(project);            
		            javaTask.setFork(true);
		            javaTask.setFailonerror(true);
		            
		            Path path = new Path(project, System.getProperty("java.class.path") + File.pathSeparator + 
		            		this.getClass().getProtectionDomain().getCodeSource().getLocation().getPath());
		            
					File f = new File(this.getClass().getProtectionDomain().getCodeSource().getLocation().getFile());
					String dir = "\"" + f.toURI().toASCIIString().replace("file:", "file:///") + "\"";
		            LOGGER.info("UPDATER: path: " + path);
		            
		            javaTask.setClasspath(path);            
		            javaTask.setClassname(edu.northwestern.dasu.util.UpdaterV2.class.getName());
		            javaTask.init();
		            
		            javaTask.executeJava();		            
		
		        } catch (BuildException e) {
		                caught = e;
		                e.printStackTrace();
		        }
			
			}
		};
		
		Thread t = new Thread(verifierServer);
		t.start();
			
		LOGGER.info("UPDATER: Initializing RulesVerifier client");
		long startTime = System.currentTimeMillis();
		verifierClient = new SocketClient("localhost", 1234);
		while ( !verifierClient.connected && (System.currentTimeMillis() - startTime) < timeout*1000 ) {
			verifierClient.connect();
		}
			
		if ( System.currentTimeMillis() - startTime < timeout*1000) {
			ready = true;
			LOGGER.info("UPDATER: RulesVerifier initialized");
		}
		else {
			failed = true;
			LOGGER.severe("UPDATER: rulesVerifier is not starting properly... all verifications will fail");
		}
		
			
		
	}
	
	public void disconnect() {
		
		if (verifierClient != null)
			verifierClient.disconnect();
	}
	
	public boolean sendVerificationRequest(String fileName) throws Exception{
				
		if ( verifierClient != null && verifierClient.connected )
			return verifierClient.sendRequestVerification(fileName, timeout);
		
		return false;
	}
	
	public class SocketClient {
		
        Socket echoSocket = null;
        PrintWriter out = null;
        BufferedReader in = null; 
        boolean connected = false;
        
        String serverHostname;
        Integer serverPort;
        
        public SocketClient(String server, int port) {
        	serverHostname = new String (server);
        	serverPort = port;
        }
        
        private void connect() {
        	
        	try {
	            echoSocket = new Socket(serverHostname, serverPort);
	            out = new PrintWriter(echoSocket.getOutputStream(), true);
	            in = new BufferedReader(new InputStreamReader(echoSocket.getInputStream()));
	            connected = true;
        	}
        	catch (Exception e) {
        		//e.printStackTrace();
        	}

        }
        
        private void disconnect() {
        	
        	try {
        		if ( connected ) { 
		        	out.println("Bye.");
					out.close();
					in.close();
					echoSocket.close();
        		}
        	}
        	catch (Exception e) {
        		e.printStackTrace();
        	}

        }
        
        public boolean sendRequestVerification(String file, int timeout)  throws Exception {
        	
    		long startTime = System.currentTimeMillis();        		
        	out.println(file);
        	String serverOutput;
        	while ((serverOutput = in.readLine()) == null && (System.currentTimeMillis() - startTime) < timeout*1000);        	
        	
        	if ( System.currentTimeMillis() - startTime < timeout*1000)
        		return serverOutput.equals("true");
        	
        	throw new Exception("timeout");
        }
		
	}
	
	public static void main(String args[]) throws Exception {
		
		java.util.logging.Logger LOGGER = java.util.logging.Logger.getLogger("edu.northwestern.dasu");
		RulesVerifier rv = new RulesVerifier(LOGGER);		
		rv.initRulesVerifier();			
		boolean result = rv.sendVerificationRequest("/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/testdasu/plugins/dasu/DasuUiRulesModules_4.0.jar");
		System.out.println(result);
		result = rv.sendVerificationRequest("/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/testdasu/plugins/dasu/DasuUiRulesModules_2.8.jar");
		System.out.println(result);
		result = rv.sendVerificationRequest("/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/testdasu/plugins/dasu/DasuUiRulesModules_4.0.jar");
		System.out.println(result);
		        		
	}
}

==> dasu_5.1.jar: edu/northwestern/dasu/util/RulesVerifier.java <==
/**
 * Dasu Project
 *
 * File:         RulesVerifier.java
 * RCS:          $Id: RulesVerifier.java,v 1.0 Jan 13, 2013 11:18:13 AM mas939 Exp $
 * Description:  RulesVerifier class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Jan 13, 2013 at 11:18:13 AM
 * Language:     Java
 * Package:      edu.northwestern.dasu.util
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2013, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.util;

import java.io.BufferedReader;
import java.io.File;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.net.Socket;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.DefaultLogger;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.taskdefs.Java;
import org.apache.tools.ant.types.Path;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The RulesVerifier class ...
 */
public class RulesVerifier {

	java.util.logging.Logger LOGGER;
	
	Runnable verifierServer = null;
	SocketClient verifierClient = null;	
	int timeout = 10; //seconds
	boolean ready = false;
	boolean failed = false;
	
	public RulesVerifier(java.util.logging.Logger logger){
		LOGGER = logger;
	}	
		
	public void initRulesVerifier() {
		
		LOGGER.info("UPDATER: initializing dynamic rules verifier...");
		verifierServer = new Runnable() {
			
			public void run() {
								
		        Project project = new Project();
		        project.setBaseDir(new File(System.getProperty("user.dir")));
		        project.init();
		        DefaultLogger logger = new DefaultLogger();
		        project.addBuildListener(logger);
		
		        logger.setOutputPrintStream(System.err);        
		        logger.setErrorPrintStream(System.err);
		        //logger.setMessageOutputLevel(Project.MSG_ERR);
		        
		        project.fireBuildStarted();
		    	logger.setMessageOutputLevel(Project.MSG_INFO);
				        
		        try {
			        	
		    		Java javaTask = new Java();	    		
		            javaTask.setTaskName("rulesVerifier");
		            javaTask.setProject(project);            
		            javaTask.setFork(true);
		            javaTask.setFailonerror(true);
		            
		            Path path = new Path(project, System.getProperty("java.class.path") + File.pathSeparator + 
		            		this.getClass().getProtectionDomain().getCodeSource().getLocation().getPath());
		            
					//File f = new File(this.getClass().getProtectionDomain().getCodeSource().getLocation().getFile());
					//String dir = "\"" + f.toURI().toASCIIString().replace("file:", "file:///") + "\"";
		            LOGGER.info("UPDATER: path: " + path);
		            
		            javaTask.setClasspath(path);            
		            javaTask.setClassname(edu.northwestern.dasu.util.UpdaterV2.class.getName());
		            javaTask.init();
		            
		            javaTask.executeJava();		            
		
		        } catch (BuildException e) {
		        	LOGGER.warning("UPDATER: " + e.getMessage());
		        }
			
			}
		};
		
		Thread t = new Thread(verifierServer);
		t.start();
			
		LOGGER.info("UPDATER: Initializing RulesVerifier client");
		long startTime = System.currentTimeMillis();
		verifierClient = new SocketClient("localhost", 29999);
		while ( !verifierClient.connected && (System.currentTimeMillis() - startTime) < timeout*1000 ) {
			verifierClient.connect();
		}
			
		if ( System.currentTimeMillis() - startTime < timeout*1000) {
			ready = true;
			LOGGER.info("UPDATER: RulesVerifier initialized");
		}
		else {
			failed = true;
			LOGGER.severe("UPDATER: rulesVerifier is not starting properly... all verifications will fail");
		}
		
			
		
	}
	
	public void disconnect() {
		
		if (verifierClient != null)
			verifierClient.disconnect();
	}
	
	public boolean sendVerificationRequest(String fileName) throws Exception{
				
		if ( verifierClient != null && verifierClient.connected )
			return verifierClient.sendRequestVerification(fileName, timeout);
		
		return false;
	}
	
	public class SocketClient {
		
        Socket echoSocket = null;
        PrintWriter out = null;
        BufferedReader in = null; 
        boolean connected = false;
        
        String serverHostname;
        Integer serverPort;
        
        public SocketClient(String server, int port) {
        	serverHostname = new String (server);
        	serverPort = port;
        }
        
        private void connect() {
        	
        	try {
	            echoSocket = new Socket(serverHostname, serverPort);
	            out = new PrintWriter(echoSocket.getOutputStream(), true);
	            in = new BufferedReader(new InputStreamReader(echoSocket.getInputStream()));
	            connected = true;
        	}
        	catch (Exception e) {
        		//e.printStackTrace();
        	}

        }
        
        private void disconnect() {
        	
        	try {
        		if ( connected ) { 
		        	out.println("Bye.");
					out.close();
					in.close();
					echoSocket.close();
        		}
        	}
        	catch (Exception e) {
        		e.printStackTrace();
        	}

        }
        
        public boolean sendRequestVerification(String file, int timeout)  throws Exception {
        	
    		long startTime = System.currentTimeMillis();        		
        	out.println(file);
        	String serverOutput;
        	while ((serverOutput = in.readLine()) == null && (System.currentTimeMillis() - startTime) < timeout*1000);        	
        	
        	if ( System.currentTimeMillis() - startTime < timeout*1000)
        		return serverOutput.equals("true");
        	
        	throw new Exception("timeout");
        }
		
	}
	
	public static void main(String args[]) throws Exception {
		
		java.util.logging.Logger LOGGER = java.util.logging.Logger.getLogger("edu.northwestern.dasu");
		RulesVerifier rv = new RulesVerifier(LOGGER);		
		rv.initRulesVerifier();			
		boolean result = rv.sendVerificationRequest("/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/testdasu/plugins/dasu/DasuUiRulesModules_4.0.jar");
		System.out.println(result);
		result = rv.sendVerificationRequest("/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/testdasu/plugins/dasu/DasuUiRulesModules_2.8.jar");
		System.out.println(result);
		result = rv.sendVerificationRequest("/Users/mas939/Mario's Stuff/NORTHWESTERN/Dropbox/workspace/ISP Interference/testdasu/plugins/dasu/DasuUiRulesModules_4.0.jar");
		System.out.println(result);
		        		
	}
}
